@@ -167,8 +167,10 @@ class AsyncKafkaSubscriber(AsyncSubscriber):
         return msg.value, msg
 
     def _process_received_task(self, payload: bytes, meta: ConsumerRecord) -> Task:
-        task = super()._process_received_task(payload, meta)
-        task.meta.queue_name = meta.topic
+        task = super()._process_received_task(payload, {
+            **dict(meta.headers),
+            'queue_name': meta.topic,
+        })
         # keep some metadata about task for commit
         self._task_meta[task.uuid] = (
             meta.topic,
@@ -408,12 +410,21 @@ class AssignKafkaSubscriber(AsyncKafkaSubscriber):
             # seek to the end of each new topic subscribed so no historical messages will be fetched
             await self.consumer.seek_to_end(*new_topics)
 
+        # manually call revoke/assign callbacks
+        await self.handle_partitions_revoke(assignment)
+        await self.handle_partitions_assignment(topics)
+
     async def unsubscribe(self, queue_name: Iterable[str]):
         queues: Set[TopicPartition] = set(TopicPartition(topic=t, partition=0) for t in queue_name)
-        topics = self.consumer.assignment() ^ queues
+        assignment = self.consumer.assignment()
+        topics = assignment ^ queues
 
         self.consumer.assign(list(topics))
 
+        # manually call revoke/assign callbacks
+        await self.handle_partitions_revoke(assignment)
+        await self.handle_partitions_assignment(topics)
+
     async def commit(self, task: Task, timeout: float = None):
         # no commits if no consumer group
         if not self.settings.consumer_group:
